
# pynometrics package
 ml_processor is a package for data preprocessing and fitting machine learning models 

 # Installation

 Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pynometrics

 ```bash
pip install ml_processor
```

# Usage
 ```python
 import ml_processor as ec
  ```

 ## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)